/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.realm;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.Spy;

class KeycloakRealmMapperTest {

	@Spy
	private final KeycloakRealmMapper mapper = Mappers.getMapper(KeycloakRealmMapper.class);

	@Test
	void shouldMapDisplayName() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.getDisplayName()).isEqualTo(OzgCloudKeycloakRealmSpecTestFactory.DISPLAY_NAME);
	}

	@Test
	void shouldBeEnabled() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.isEnabled()).isTrue();
	}

	@Test
	void shouldBeResetPasswordAllowed() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.isResetPasswordAllowed()).isTrue();
	}

	@Test
	void shouldBeSupportedLocaleDe() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.getSupportedLocales()).containsExactly("de");
	}

	@Test
	void shouldBeDefaultLocaleDe() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.getDefaultLocale()).isEqualTo("de");
	}

	@Test
	void shouldBeInternationalizationEnabled() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.isInternationalizationEnabled()).isTrue();
	}

	@Test
	void checkPasswordPolicy() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.getPasswordPolicy()).isEqualTo("upperCase(1) and lowerCase(1) and length(8) and notUsername");
	}

	@Test
	void shouldSetActionTokenGeneratedByUserLifespan() {
		var mapped = mapper.map(OzgCloudKeycloakRealmSpecTestFactory.create());

		assertThat(mapped.getActionTokenGeneratedByUserLifespan()).isEqualTo(900);
	}
}
